USE [AdminSQLskills]
GO

/****** Object:  Table [dbo].[SQLskills_StatsHistory]    Script Date: 1/4/2022 10:42:48 PM ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[SQLskills_StatsHistory](
	[CaptureDate] [datetime2](7) NOT NULL,
	[DatabaseID] [smallint] NULL,
	[TableName] [nvarchar](257) NOT NULL,
	[Statistic] [nvarchar](128) NULL,
	[WasAutoCreated] [bit] NULL,
	[WasUserCreated] [bit] NULL,
	[IsFiltered] [bit] NULL,
	[FilterDefinition] [nvarchar](2048) NULL,
	[IsTemporary] [bit] NULL,
	[StatsLastUpdated] [datetime2](7) NULL,
	[RowsInTable] [bigint] NULL,
	[RowsSampled] [bigint] NULL,
	[UnfilteredRows] [bigint] NULL,
	[RowModifications] [bigint] NULL,
	[PersistedSamplePercent] [float] NULL,
	[NoRecompute] [bit] NULL,
	[HistogramSteps] [int] NULL
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[SQLskills_StatsHistory] ADD  DEFAULT (sysdatetime()) FOR [CaptureDate]
GO



IF sys.fn_hadr_is_primary_replica ('MedRecords') = 1
BEGIN

USE MedRecords


INSERT INTO [AdminSQLskills].[dbo].[SQLskills_StatsHistory]
           ([DatabaseID]
           ,[TableName]
           ,[Statistic]
           ,[WasAutoCreated]
           ,[WasUserCreated]
           ,[IsFiltered]
           ,[FilterDefinition]
           ,[IsTemporary]
           ,[StatsLastUpdated]
           ,[RowsInTable]
           ,[RowsSampled]
           ,[UnfilteredRows]
           ,[RowModifications]
           ,[PersistedSamplePercent]
           ,[NoRecompute]
           ,[HistogramSteps])
SELECT  
		DB_NAME(DB_ID()) AS [DBName],
		[sch].[name] + '.' + [so].[name] AS [TableName] ,
        [ss].[name] AS [Statistic] ,
        [ss].[auto_Created] AS [WasAutoCreated] ,
        [ss].[user_created] AS [WasUserCreated] ,
        [ss].[has_filter] AS [IsFiltered] ,
        [ss].[filter_definition] AS [FilterDefinition] ,
        [ss].[is_temporary] AS [IsTemporary] ,
        [sp].[last_updated] AS [StatsLastUpdated] ,
        [sp].[rows] AS [RowsInTable] ,
        [sp].[rows_sampled] AS [RowsSampled] ,
        [sp].[unfiltered_rows] AS [UnfilteredRows] ,
        [sp].[modification_counter] AS [RowModifications] ,
		[sp].[persisted_sample_percent] AS [PersistedSamplePercent],
		[ss].[no_recompute] AS [NoRecompute],
        [sp].[steps] AS [HistogramSteps]
FROM    [sys].[stats] [ss]
        JOIN [sys].[objects] [so] ON [ss].[object_id] = [so].[object_id]
        JOIN [sys].[schemas] [sch] ON [so].[schema_id] = [sch].[schema_id]
        OUTER APPLY [sys].[dm_db_stats_properties]([so].[object_id],
                                                   [ss].[stats_id]) sp
WHERE   [so].[type] = 'U'
ORDER BY [so].[name], [ss].[name]

END


DELETE FROM [AdminSQLskills].[dbo].[SQLskills_StatsHistory]
WHERE [CaptureDate] < GETDATE() - 30






